body {
  margin: 0;
  padding: 0;
  overflow: hidden;
}

#deck-map-container {
  width: 100%;
  height: 100%;
  background-color: black;
}

#map {
  pointer-events: none;
  height: 100%;
  width: 100%;
  position: absolute;
  z-index: 1;
}

#deckgl-overlay {
  z-index: 2;
  background: {{css_background_color or 'none'}};
}

#deck-map-wrapper {
  width: 100%;
  height: 100%;
}

#deck-container {
  width: 100vw;
  height: 100vh;
}
